Class: SDL2::Event
- Inherits:
-
FFI::Union
- Object
- FFI::Union
- SDL2::Event
- Defined in:
- lib/sdl2/events.rb
Overview
General event UNION (structure) Remember that this is a union, all other structures not related to #type are garbage
General event UNION (structure) Remember that this is a union, all other structures not related to #type are garbage