Class: SDL2::Haptic::LeftRight

Inherits:
Struct
  • Object
show all
Defined in:
lib/sdl2/haptic.rb

Overview

brief A structure containing a template for a Left/Right effect.

This struct is exclusively for the ::SDL_HAPTIC_LEFTRIGHT effect.

The Left/Right effect is used to explicitly control the large and small motors, commonly found in modern game controllers. One motor is high frequency, the other is low frequency.

sa SDL_HAPTIC_LEFTRIGHT sa SDL_HapticEffect

Method Summary

Methods inherited from Struct

#==, #initialize, #inspect, member_readers, member_writers, release

Constructor Details

This class inherits a constructor from SDL2::Struct